## DDH X-Ray

Retuve runs a single DDH X-Ray Model, which measures the Acetabular Index.

This is visualised by an image created when Retuve Runs.

<img src="https://github.com/radoss-org/radoss-creative-commons/blob/main/other/xray/331_DDH_115_processed.jpg?raw=true" alt="drawing" width="500"/>

Attribution of the above X-Ray Images: Fraiwan, Mohammad; Al-Kofahi, Noran; Hanatleh, Omar; ibnian, ali (2022), “A dataset of DDH x-ray images”, Mendeley Data, V2, doi: 10.17632/jf3pv98m9g.2

For how to run these models yourself, see the examples: https://github.com/radoss-org/retuve/tree/main/examples/